:mod:`art.classifiers`
======================
.. automodule:: art.classifiers

BlackBox Wrapper
----------------
.. autoclass:: BlackBoxClassifier
   :members:
   :special-members:

Keras Wrapper
-------------
.. autoclass:: KerasClassifier
   :members:
   :special-members:

MXNet Wrapper
-------------
.. autoclass:: MXClassifier
   :members:
   :special-members:

PyTorch Wrapper
---------------
.. autoclass:: PyTorchClassifier
   :members:
   :special-members:

TensorFlow Wrapper
------------------
.. autoclass:: TensorFlowClassifier
   :members:
   :special-members:

TensorFlow v2 Wrapper
---------------------
.. autoclass:: TensorFlowV2Classifier
   :members:
   :special-members:

Ensemble Wrapper
----------------
.. autoclass:: EnsembleClassifier
   :members:
   :special-members:

Scikit-learn Classifier Wrapper
-------------------------------
.. autofunction:: SklearnClassifier

GPy Gaussian Process Wrapper
----------------------------
.. autoclass:: GPyGaussianProcessClassifier
   :members:
   :special-members:

Base Class
----------
.. autoclass:: Classifier
   :members:

Base Class Neural Network
-------------------------
.. autoclass:: ClassifierNeuralNetwork
   :members:

Base Class Gradients
--------------------
.. autoclass:: ClassifierGradients
   :members:
